summaryrefslogtreecommitdiffstats
path: root/knotes/KNotesIface.h
diff options
context:
space:
mode:
Diffstat (limited to 'knotes/KNotesIface.h')
-rw-r--r--knotes/KNotesIface.h26
1 files changed, 13 insertions, 13 deletions
diff --git a/knotes/KNotesIface.h b/knotes/KNotesIface.h
index b1d22de3..dc9cd41d 100644
--- a/knotes/KNotesIface.h
+++ b/knotes/KNotesIface.h
@@ -22,8 +22,8 @@
#ifndef __KNotesIface_h__
#define __KNotesIface_h__
-#include <qstring.h>
-#include <qmap.h>
+#include <tqstring.h>
+#include <tqmap.h>
#include <dcopobject.h>
@@ -39,8 +39,8 @@ k_dcop:
* @param text the body of the new note
* @return the new notes' id
*/
- virtual QString newNote( const QString& name = QString::null,
- const QString& text = QString::null ) = 0;
+ virtual TQString newNote( const TQString& name = TQString::null,
+ const TQString& text = TQString::null ) = 0;
/**
* Create a new note and inserts the current text in the clipboard
@@ -50,54 +50,54 @@ k_dcop:
* KNotes will choose an appropriate name
* @return the new notes' id
*/
- virtual QString newNoteFromClipboard( const QString& name = QString::null ) = 0;
+ virtual TQString newNoteFromClipboard( const TQString& name = TQString::null ) = 0;
/**
* Deletes a note forever.
* @param noteId the id of the note to kill
*/
- virtual ASYNC killNote( const QString& noteId ) = 0;
+ virtual ASYNC killNote( const TQString& noteId ) = 0;
/**
* Deletes a note forever.
* @param noteId the id of the note to kill
* @param force do not request confirmation
*/
- virtual ASYNC killNote( const QString& noteId, bool force ) = 0;
+ virtual ASYNC killNote( const TQString& noteId, bool force ) = 0;
/**
* Get all the notes including their ids.
* @return a QMap that maps the id of a note to its name
*/
- virtual QMap<QString,QString> notes() const = 0;
+ virtual TQMap<TQString,TQString> notes() const = 0;
/**
* Changes the title/name of a note.
* @param noteId the id of the note to be modified
* @param newName the new title
*/
- virtual ASYNC setName( const QString& noteId, const QString& newName ) = 0;
+ virtual ASYNC setName( const TQString& noteId, const TQString& newName ) = 0;
/**
* Sets the text of a note. This will delete the old text!
* @param noteId the id of the note
* @param newText the new text for the note
*/
- virtual ASYNC setText( const QString& noteId, const QString& newText ) = 0;
+ virtual ASYNC setText( const TQString& noteId, const TQString& newText ) = 0;
/**
* Returns the title/name of a note.
* @param noteId the id of the note in question
* @return the name as a QString
*/
- virtual QString name( const QString& noteId ) const = 0;
+ virtual TQString name( const TQString& noteId ) const = 0;
/**
* Returns the text of a note.
* @param noteId the id of the note in question
* @return the body as a QString
*/
- virtual QString text( const QString& noteId ) const = 0;
+ virtual TQString text( const TQString& noteId ) const = 0;
};
#endif
@@ -50,54 +50,54 @@ k_dcop:
/**
* Get all the notes including their ids.
- * @return a QMap that maps the id of a note to its name
+ * @return a TQMap that maps the id of a note to its name
*/